@@ -1,8 +1,15 @@
 #' Standard Deviation of a collection of spectra
 #'
-#' A method to compute the standard deviation of values across members of a
-#' collections of spectra. Computes the standard deviation at each wavelength
-#' across all the spectra in the collection returning a spectral object.
+#' Method to compute the "parallel" standard deviation of values across members
+#' of a collection of spectra or of a spectral object containing multiple
+#' spectra in long form.
+#'
+#' @details Method specializations compute the standard deviation at each
+#'   wavelength across a group of spectra stored in an object of one of the
+#'   classes defined in package 'photobiology'. Omission of NAs is done
+#'   separately at each wavelength. Interpolation is not applied, so all spectra
+#'   in \code{x} must share the same set of wavelengths. An error is triggered
+#'   if this condition is nor fulfilled.
 #'
 #' @param x An R object. Currently this package defines methods for collections
 #'   of spectral objects.
@@ -11,24 +18,26 @@
 #' @param ...	Further arguments passed to or from other methods.
 #'
 #' @return If \code{x} is a collection spectral of objects, such as a
-#'   "filter_mspct" object, the returned object is of class "generic_spct",
-#'   containing the standard deviation among the spectra at each wavelength
-#'   in a column with name ending in ".sd".
+#'   \code{"filter_mspct"} object, the returned object is of same class as the
+#'   members of the collection, such as \code{"filter_spct"}, containing the
+#'   summary spectrum, with variables with names tagged for summaries other
+#'   than mean or median.
 #'
-#' @note Omission of NAs is done separately at each wavelength. Interpolation is
-#'   not applied, so all spectra in \code{x} must share the same set of
-#'   wavelengths.
-#'
-#'   Objects of classes raw_spct and cps_spct can contain data from multiple
-#'   scans. This functions are implemented for these classes only for the case
-#'   when all member spectra contain data for a single scan, or spliced into a
-#'   single column in the case of cps_spct members.
+#' @note Objects of classes \code{raw_spct} and \code{cps_spct} can contain data
+#'   from multiple scans in multiple variables or "columns". The methods accept
+#'   as arguments objects of these classes only if spectra contain data for a
+#'   single spectrometer scan. In the case of \code{cps_spct} objects, a single
+#'   column can also contain data from multiple scans spliced into a single
+#'   variable.
 #'
 #' @seealso See \code{\link[stats]{sd}} for details about \code{sd()} methods
 #'   for other classes.
 #'
 #' @export
 #'
+#' @examples
+#' s_sd(sun_evening.mspct)
+#'
 s_sd <- function(x, na.rm, ...)
   UseMethod("s_sd")
 
@@ -43,6 +52,14 @@ s_sd.default <- function(x, na.rm = FALSE, ...) {
   ifelse(is.any_mspct(x), generic_spct(), NA)
 }
 
+#' @describeIn s_sd
+#'
+#' @export
+#'
+s_sd.generic_spct <- function(x, na.rm = FALSE, ...) {
+  s_sd(subset2mspct(x), na.rm = na.rm, ...)
+}
+
 #' @describeIn s_sd
 #'
 #' @export
